@@ -1,3 +1,4 @@
+from contextlib import nullcontext
 import os
 import streamlit.components.v1 as components
 
@@ -43,7 +44,7 @@ else:
 # `declare_component` and call it done. The wrapper allows us to customize
 # our component's API: we can pre-process its input args, post-process its
 # output value, and add a docstring for users.
-def streamlit_alert(message, severity="info", title=None, variant="standard", snackbar=False):
+def streamlit_alert(message, severity="info", title=None, variant="standard", snackbar=False, is_first_snackbar=False, padding_from_top=500):
     """Create a new instance of "streamlit_alert".
 streamlit_pagination
     Parameters
@@ -70,7 +71,7 @@ streamlit_pagination
     #
     # "default" is a special argument that specifies the initial return
     # value of the component before the user has interacted with it.
-    component_value = _component_func(message=message, severity=severity, title=title, variant=variant, snackbar=snackbar)
+    component_value = _component_func(message=message, severity=severity, title=title, variant=variant, snackbar=snackbar,is_first_snackbar=is_first_snackbar,  padding_from_top=padding_from_top)
 
     # We could modify the value returned from the component if we wanted.
     # There's no need to do this in our simple example - but it's an option.
@@ -107,8 +108,9 @@ if not _RELEASE:
 
     with st.sidebar:
         st.header("SnackBar alerts")
-        streamlit_alert("This is an error alert — check it out!", "error", variant="filled", snackbar=True)
-
-    streamlit_alert("This is a success alert — check it out!", "success", snackbar=True)
+        streamlit_alert("This is an error alert", "error", variant="filled", snackbar=True, is_first_snackbar=True, padding_from_top=500)
+        streamlit_alert("This is an error alert", "success", variant="outlined", snackbar=True, is_first_snackbar=False)
 
+    # streamlit_alert("This is a success alert — check it out!", "success", snackbar=True)
+    
 
